package com.muyu.cloud.mart.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.muyu.cloud.mart.mapper.UserMapper;
import com.muyu.cloud.mart.service.UserService;
import com.muyu.common.core.domain.Result;
import com.muyu.domain.User;
import com.muyu.domain.UserSearch;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * @Author：chaiyapeng
 * @Package：com.muyu.cloud.mart.service.impl
 * @Project：cloud-mart
 * @name：UserServiceImpl
 * @Date：2024/8/22 15:29
 */
@Service
public class UserServiceImpl extends ServiceImpl<UserMapper, User> implements UserService {
    @Autowired
    private UserMapper userMapper;

    @Override
    public List<User> getAllUsers() {
        List<User> list = userMapper.selectList(null);
        return list;
    }

    @Override
    public Result addUser(User user) {
        Integer i = userMapper.insert(user);
        if (i>0){
            return Result.success(i,"添加成功");
        }else {
            return Result.error("添加失败");
        }
    }

    @Override
    public Result updateUser(User user) {
        Integer i = userMapper.updateById(user);
        if (i>0){
            return Result.success(i,"更新成功");
        }else{
            return Result.error("更新失败");
        }
    }

    @Override
    public Result deleteUser(User user) {
        Integer i = userMapper.deleteById(user);
        if (i>0){
            return Result.success(i,"删除成功");
        }else {
            return Result.error("删除失败");
        }
    }

    @Override
    public Result getAllUserByCon(UserSearch userSearch) {
        QueryWrapper<User> wrapper = new QueryWrapper<>();
        if (userSearch.getBlur()!=null && !userSearch.getBlur().equals("")){
            wrapper.like("user_name",userSearch.getBlur());
        }
        List<User> list = userMapper.selectList(wrapper);
        return Result.success(list);
    }
}
